==> rc-ui-lib-2.1.1.tgz: package/lib/tabbar/TabbarItem.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_classnames = __toESM(require("classnames"));
var import_TabbarContext = __toESM(require("./TabbarContext"));
var import_icon = require("../icon");
var import_badge = require("../badge");
var import_ConfigProviderContext = __toESM(require("../config-provider/ConfigProviderContext"));
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
const TabbarItem = (props) => {
  const {
    setActive,
    index
  } = props;
  const {
    prefixCls,
    createNamespace
  } = (0, import_react.useContext)(import_ConfigProviderContext.default);
  const [bem] = createNamespace("tabbar-item", prefixCls);
  const {
    parent
  } = (0, import_react.useContext)(import_TabbarContext.default);
  const {
    activeColor,
    inactiveColor
  } = parent;
  if (!parent) {
    if (process.env.NODE_ENV !== "production") {
      console.error("[rc-ui-lib] <TabbarItem> must be a child component of <Tabbar>.");
    }
  }
  const active = (0, import_react.useMemo)(() => {
    return (props.name || index) === parent.value;
  }, [props.name, index, parent.value]);
  const onClick = (event) => {
    var _a, _b;
    setActive((_a = props.name) != null ? _a : index);
    (_b = props.onClick) == null ? void 0 : _b.call(props, event);
  };
  const renderIcon = () => {
    if (typeof props.icon === "string") {
      return /* @__PURE__ */ import_react.default.createElement(import_icon.Icon, {
        name: props.icon,
        classPrefix: props.iconPrefix
      });
    }
    if (typeof props.icon === "function") {
      return props.icon(active);
    }
    return null;
  };
  const color = active ? activeColor : inactiveColor;
  return /* @__PURE__ */ import_react.default.createElement("div", {
    className: (0, import_classnames.default)(props.className, bem({
      active
    })),
    style: __spreadProps(__spreadValues({}, props.style), {
      color
    }),
    onClick
  }, /* @__PURE__ */ import_react.default.createElement(import_badge.Badge, _extends({}, props.badge, {
    className: (0, import_classnames.default)(bem("icon"))
  }), renderIcon()), /* @__PURE__ */ import_react.default.createElement("div", {
    className: (0, import_classnames.default)(bem("text"))
  }, typeof props.children === "function" ? props.children(active) : props.children));
};
var stdin_default = TabbarItem;

==> rc-ui-lib-2.1.3.tgz: package/lib/tabbar/TabbarItem.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_classnames = __toESM(require("classnames"));
var import_TabbarContext = __toESM(require("./TabbarContext"));
var import_icon = require("../icon");
var import_badge = require("../badge");
var import_ConfigProviderContext = __toESM(require("../config-provider/ConfigProviderContext"));
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t)
        ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
const TabbarItem = (props) => {
  const {
    setActive,
    index
  } = props;
  const {
    prefixCls,
    createNamespace
  } = (0, import_react.useContext)(import_ConfigProviderContext.default);
  const [bem] = createNamespace("tabbar-item", prefixCls);
  const {
    parent
  } = (0, import_react.useContext)(import_TabbarContext.default);
  const {
    activeColor,
    inactiveColor
  } = parent;
  if (!parent) {
    if (process.env.NODE_ENV !== "production") {
      console.error("[rc-ui-lib] <TabbarItem> must be a child component of <Tabbar>.");
    }
  }
  const active = (0, import_react.useMemo)(() => {
    return (props.name || index) === parent.value;
  }, [props.name, index, parent.value]);
  const onClick = (event) => {
    var _a, _b;
    setActive((_a = props.name) != null ? _a : index);
    (_b = props.onClick) == null ? void 0 : _b.call(props, event);
  };
  const renderIcon = () => {
    if (typeof props.icon === "string") {
      return /* @__PURE__ */ import_react.default.createElement(import_icon.Icon, {
        name: props.icon,
        classPrefix: props.iconPrefix
      });
    }
    if (typeof props.icon === "function") {
      return props.icon(active);
    }
    return null;
  };
  const color = active ? activeColor : inactiveColor;
  return /* @__PURE__ */ import_react.default.createElement("div", {
    className: (0, import_classnames.default)(props.className, bem({
      active
    })),
    style: __spreadProps(__spreadValues({}, props.style), {
      color
    }),
    onClick
  }, /* @__PURE__ */ import_react.default.createElement(import_badge.Badge, _extends({}, props.badge, {
    className: (0, import_classnames.default)(bem("icon"))
  }), renderIcon()), /* @__PURE__ */ import_react.default.createElement("div", {
    className: (0, import_classnames.default)(bem("text"))
  }, typeof props.children === "function" ? props.children(active) : props.children));
};
var stdin_default = TabbarItem;
